Module: Ucode::Commands
- Defined in:
- lib/ucode/commands.rb,
lib/ucode/commands/site.rb,
lib/ucode/commands/audit.rb,
lib/ucode/commands/build.rb,
lib/ucode/commands/cache.rb,
lib/ucode/commands/fetch.rb,
lib/ucode/commands/parse.rb,
lib/ucode/commands/glyphs.rb,
lib/ucode/commands/lookup.rb,
lib/ucode/commands/release.rb,
lib/ucode/commands/block_feed.rb,
lib/ucode/commands/font_coverage.rb,
lib/ucode/commands/universal_set.rb,
lib/ucode/commands/canonical_build.rb,
lib/ucode/commands/audit/font_command.rb,
lib/ucode/commands/audit/browser_command.rb,
lib/ucode/commands/audit/compare_command.rb,
lib/ucode/commands/audit/library_command.rb,
lib/ucode/commands/audit/collection_command.rb
Overview
Commands — one Thor class per CLI subcommand.
Each command delegates the actual work to a *Command::Action (or
similar) structured-result class. The Thor method is purely dispatch
- formatting. This keeps Thor thin and the work testable in-process.
Defined Under Namespace
Modules: Audit, UniversalSet Classes: BlockFeedCommand, BuildCommand, CacheCommand, CanonicalBuildCommand, FetchCommand, FontCoverageCommand, GlyphsCommand, LookupCommand, ParseCommand, ReleaseCommand, SiteCommand