Class: Ucode::Glyphs::EmbeddedFonts::ContentStreamCorrelator::Config

Inherits:
Struct
  • Object
show all
Defined in:
lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb

Overview

Per-font / per-block configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#label_font_idsObject (readonly)

Type0 font object IDs whose glyphs print the hex codepoint labels on the page.



27
28
29
30
31
32
# File 'lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb', line 27

Config = Struct.new(
  :label_font_ids,
  :specimen_font_id,
  :page_numbers,
  keyword_init: true,
)

#page_numbersObject (readonly)

1-based PDF page numbers whose content streams reference the specimen font.



27
28
29
30
31
32
# File 'lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb', line 27

Config = Struct.new(
  :label_font_ids,
  :specimen_font_id,
  :page_numbers,
  keyword_init: true,
)

#specimen_font_idObject (readonly)

Type0 font object ID whose glyphs are the specimens we want to attribute.



27
28
29
30
31
32
# File 'lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb', line 27

Config = Struct.new(
  :label_font_ids,
  :specimen_font_id,
  :page_numbers,
  keyword_init: true,
)