Class: Ucode::Models::ValidationReport::CheckSummary

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/ucode/models/validation_report.rb

Overview

Per-check summary. status is one of passed / failed / skipped. total is the number of codepoints the check evaluated against (0 for skipped). failures is the count of recorded failures for this check.

Constant Summary collapse

STATUS_PASSED =
"passed"
STATUS_FAILED =
"failed"
STATUS_SKIPPED =
"skipped"