Exception: Ucode::Fetch::Http::ValidationFailure
- Inherits:
-
StandardError
- Object
- StandardError
- Ucode::Fetch::Http::ValidationFailure
- Defined in:
- lib/ucode/fetch/http.rb
Overview
Internal carrier for a validation failure inside a retry attempt. Re-raised from the loop so the response body (which is partial on retries) isn't double-validated against truncated bytes.
Instance Attribute Summary collapse
-
#cause ⇒ Object
readonly
Returns the value of attribute cause.
Instance Method Summary collapse
-
#initialize(cause) ⇒ ValidationFailure
constructor
A new instance of ValidationFailure.
Constructor Details
#initialize(cause) ⇒ ValidationFailure
Returns a new instance of ValidationFailure.
79 80 81 82 |
# File 'lib/ucode/fetch/http.rb', line 79 def initialize(cause) @cause = cause super(cause.) end |
Instance Attribute Details
#cause ⇒ Object (readonly)
Returns the value of attribute cause.
77 78 79 |
# File 'lib/ucode/fetch/http.rb', line 77 def cause @cause end |