Class: Ucode::Glyphs::EmbeddedFonts::ContentStreamCorrelator::Config
- Inherits:
-
Struct
- Object
- Struct
- Ucode::Glyphs::EmbeddedFonts::ContentStreamCorrelator::Config
- Defined in:
- lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb
Overview
Per-font / per-block configuration.
Instance Attribute Summary collapse
-
#label_font_ids ⇒ Object
readonly
Type0 font object IDs whose glyphs print the hex codepoint labels on the page.
-
#page_numbers ⇒ Object
readonly
1-based PDF page numbers whose content streams reference the specimen font.
-
#specimen_font_id ⇒ Object
readonly
Type0 font object ID whose glyphs are the specimens we want to attribute.
Instance Attribute Details
#label_font_ids ⇒ Object (readonly)
Type0 font object IDs whose glyphs print the hex codepoint labels on the page.
27 28 29 30 31 32 |
# File 'lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb', line 27 Config = Struct.new( :label_font_ids, :specimen_font_id, :page_numbers, keyword_init: true, ) |
#page_numbers ⇒ Object (readonly)
1-based PDF page numbers whose content streams reference the specimen font.
27 28 29 30 31 32 |
# File 'lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb', line 27 Config = Struct.new( :label_font_ids, :specimen_font_id, :page_numbers, keyword_init: true, ) |
#specimen_font_id ⇒ Object (readonly)
Type0 font object ID whose glyphs are the specimens we want to attribute.
27 28 29 30 31 32 |
# File 'lib/ucode/glyphs/embedded_fonts/content_stream_correlator.rb', line 27 Config = Struct.new( :label_font_ids, :specimen_font_id, :page_numbers, keyword_init: true, ) |