Exception: Ucode::UnknownUnicodeVersionError
- Inherits:
-
LookupError
- Object
- StandardError
- Error
- LookupError
- Ucode::UnknownUnicodeVersionError
- Defined in:
- lib/ucode/error.rb
Overview
The requested Unicode version has no metadata module shipped with this gem. The context carries the requested version and the list of supported versions.
Instance Attribute Summary
Attributes inherited from Error
Method Summary
Methods inherited from Error
Constructor Details
This class inherits a constructor from Ucode::Error